# Change history for the swifttools package.

Changes to the main `swifttools` package:

- 2026 Mar 19. Release 4.0.1.
- 2026 Mar 17. Release 4.0, requires python >= 3.10.
- 2024 May 09. Migrated the sourcecode from GitLab to GitHub.

Package-specific changes:

- [ukssdc](swifttools/ukssdc/APIDocs/ukssdc/ChangeLog.md)
- [ukssdc.xrt_prods](swifttools/ukssdc/APIDocs/ukssdc/xrt_prods/ChangeLog.md)
- [swift_too](swifttools/swift_too/ChangeLog.md)
